#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent-test
version:              2.13.1.3
visibility:           public
id:                   persistent-test-2.13.1.3-5LaEDJYRo4v9U4WXubN92y
key:                  persistent-test-2.13.1.3-5LaEDJYRo4v9U4WXubN92y
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Tests for Persistent
description:
    Tests for Persistent. This is only for use in developing libraries that should conform to the persistent interface, not for users of the persistent suite of database libraries.

category:             Database, Yesod
abi:                  9cb77bc773a1d14bb347831eac292128
exposed:              True
exposed-modules:
    CompositeTest CustomPersistField CustomPersistFieldTest
    CustomPrimaryKeyReferenceTest DataTypeTest EmbedOrderTest EmbedTest
    EmptyEntityTest EntityEmbedTest EquivalentTypeTest ForeignKey
    GeneratedColumnTestSQL HtmlTest Init LargeNumberTest
    LongIdentifierTest MaxLenTest MaybeFieldDefsTest
    MigrationColumnLengthTest MigrationIdempotencyTest
    MigrationOnlyTest MigrationTest MpsCustomPrefixTest MpsNoPrefixTest
    PersistTestPetCollarType PersistTestPetType PersistUniqueTest
    PersistentTest PersistentTestModels PersistentTestModelsImports
    PrimaryTest RawSqlTest ReadWriteTest Recursive RenameTest
    SumTypeTest TransactionLevelTest TreeTest TypeLitFieldDefsTest
    UniqueTest UpsertTest

import-dirs:          /usr/lib/ghc-9.6.6/site-local/persistent-test-2.13.1.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/persistent-test-2.13.1.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/persistent-test-2.13.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-test
hs-libraries:         HSpersistent-test-2.13.1.3-5LaEDJYRo4v9U4WXubN92y
depends:
    HUnit-1.6.2.0-DydRkK1Ty562EFYgxreweA
    QuickCheck-2.15.0.1-7Xlq6KMP0mW293KZc8FCMU
    aeson-2.2.2.0-6c1DCPq2cjw7mSOIGM724W base-4.18.2.1
    blaze-html-0.9.2.0-BPrvNs5SEmQ5QlVsEK3wLT bytestring-0.11.5.3
    conduit-1.3.6.1-KgvxRslmDgl5Hh23ckCIr4 containers-0.6.7
    exceptions-0.10.7 hspec-2.11.6-EsIEtTBwugg826G6KMtBDT
    hspec-expectations-0.8.4-JRz47SURfXgGxfIuVeuxEa
    http-api-data-0.6.1-C88nqALwSmvCYnhKdwHH4H
    monad-control-1.0.3.1-51uoBWCZWabIWQnMu80nWI
    monad-logger-0.3.42-4eDd9wZLx5VADAMpzw2ja7 mtl-2.3.1
    path-pieces-0.2.1-ILPSumWqTsA51OyVDS7ISl
    persistent-2.14.5.2-IC6ObWv63c5yGhlklCrkD
    quickcheck-instances-0.3.33-8icdenp3hQoGRAS3vtTMR2
    random-1.2.1.3-2gB92M9Bgui9EHhzBvR4Sg
    resourcet-1.2.6-FMG404WUxrdL7VHJswAKQ6 text-2.0.2 time-1.12.2
    transformers-0.6.1.0
    transformers-base-0.4.6.1-8Akw4ZQOcmNnvDTfqLCuW
    unliftio-0.2.25.1-GGj9GPgXezm8HQgfatElxR
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-Hsa9d2Ja6XgAATZt7ZTK9f

haddock-interfaces:
    /usr/share/doc/haskell-persistent-test/html/persistent-test.haddock

haddock-html:         /usr/share/doc/haskell-persistent-test/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

